@@ -29,6 +29,7 @@ fn main() {
        if pos.x >= 0.0 { "positive" } else { "negative" },
        if pos.y >= 0.0 { "positive" } else { "negative" });
 
-    valf!(pos);
+    valf!(pos, pos);
+    valf!(pos, pos);
 }
 
