@@ -6,8 +6,7 @@ fn main() {
     let v3 = "i am a string";
     let n = v1.len();
 
-    info!("{:?}", v1);
-    val!(v1, n, v2);
+    val!(v1, v2, v3);
     valn!(v1, v2, v3);
-    valf!(v1, n, v2, v3);
+    valf!(v1, v2, v3, n);
 }
\ No newline at end of file
